==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Draw/Dimension/DimAligned/ts/DimAligned_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>DimAligned</name>
    <message>
        <location filename="../DimAligned.js" line="+60"/>
        <source>First extension line origin</source>
        <translatorcomment>--google--
Wskaż początek pierwszej linii rozszerzenia</translatorcomment>
        <translation type="unfinished">Pierwszym początkiem linia wewnętrzna</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Second extension line origin</source>
        <translatorcomment>--google--
Wskaż początek drugiej linii rozszerzenia</translatorcomment>
        <translation type="unfinished">Drugie źródło linia wewnętrzna</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Dimension line location</source>
        <translatorcomment>--google--
Wskaż położenie linii wymiarowej</translatorcomment>
        <translation type="unfinished">Położenie linii wymiarowej</translation>
    </message>
    <message>
        <location filename="../DimAlignedInit.js" line="+2"/>
        <source>&amp;Aligned</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
&amp;Wyrównany</translatorcomment>
        <translation type="unfinished">&amp;Wyrównany</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw aligned dimension</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Remis wyrównany wymiar</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Draw/Dimension/DimAligned/ts/DimAligned_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>DimAligned</name>
    <message>
        <location filename="../DimAligned.js" line="+60"/>
        <source>First extension line origin</source>
        <translatorcomment>--google--
Wskaż początek pierwszej linii rozszerzenia</translatorcomment>
        <translation>Początek pierwszej linii pomocniczej</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Second extension line origin</source>
        <translatorcomment>--google--
Wskaż początek drugiej linii rozszerzenia</translatorcomment>
        <translation>Początek drugiej linii pomocniczej</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Dimension line location</source>
        <translatorcomment>--google--
Wskaż położenie linii wymiarowej</translatorcomment>
        <translation>Położenie linii wymiarowej</translation>
    </message>
    <message>
        <location filename="../DimAlignedInit.js" line="+2"/>
        <source>&amp;Aligned</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
&amp;Wyrównany</translatorcomment>
        <translation>&amp;Wyrównany</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw aligned dimension</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Rysuje wymiar wyrównany</translation>
    </message>
</context>
</TS>
